pub fn get_kernel_source(
backend: GpuBackend,
kernel_type: DistanceKernelType,
) -> Result<String>Expand description
Get kernel source for the specified backend and operation
pub fn get_kernel_source(
backend: GpuBackend,
kernel_type: DistanceKernelType,
) -> Result<String>Get kernel source for the specified backend and operation