pub fn create_default_workflow(name: String) -> ClusteringWorkflowExpand description
Convenience function to create a workflow with default configuration
pub fn create_default_workflow(name: String) -> ClusteringWorkflowConvenience function to create a workflow with default configuration